import "date-fns";
import React from "react";
import {
  Button,
  Fab,
  Grid,
  TextField,
  FormControl,
  InputLabel,
  Select,
  MenuItem,
  Paper,
  Typography,
  Divider,
  Table,
  TableCell,
  TableHead,
  TableRow,
  TableBody,
  IconButton
} from "@material-ui/core";
import TrashIcon from "@material-ui/icons/Delete";
import AddIcon from "@material-ui/icons/Add";
import SaveAltIcon from "@material-ui/icons/SaveAlt";
import MoreHorizonIcon from "@material-ui/icons/MoreHoriz";
import ChevronLeftIcon from "@material-ui/icons/ChevronLeft";
import { makeStyles } from "@material-ui/core/styles";
import DateFnsUtils from "@date-io/date-fns";
import {
  MuiPickersUtilsProvider,
  KeyboardTimePicker,
  KeyboardDatePicker
} from "@material-ui/pickers";

const useStyles = makeStyles({
  grid: {
    width: "60%"
  },
  paper: {
    margin: 12,
    paddingBottom: 12
  },
  paperHeader: {
    color: "grey",
    padding: "12px"
  },
  paperHeaderBack: {
    color: "grey",
    padding: 12
  },
  paperHeaderActions: {},
  paperActions: {
    justify: "flex-end",
    padding: 0,
    margin: 0
  },
  paperActionItem: {
    paddingLeft: 40
  },
  item: {
    paddingLeft: "12px",
    paddingRight: "12px"
  },
  amount: {
    textAlign: "right"
  },
  formInput: {
    margin: 6
  },
  formContainer: {
    display: "flex"
  },
  innerContainer: {
    spacing: 12
  },
  innerLeftItem: {
    paddingLeft: 0,
    paddingRight: 12
  },
  innerRightItem: {
    paddingLeft: 12,
    paddingRight: 0
  },
  selectItem: {
    width: "100%"
  },
  textField: {
    width: "100%"
  },
  fab: {
    position: "absolute",
    bottom: 20,
    right: 20
  },
  readOnly: {
    color: "grey"
  }
});

function createData(a, b, c, d, e, f, g, h, i, j, k) {
  return { a, b, c, d, e, f, g, h, i, j, k };
}

const rowsServices = [
  createData("A1  General Consultation", "1.00", "400.00"),
  createData("I113  BLOOD SUGAR-RANDOM OR FASTING", "1.00", "1250.00")
];

const rowsItems = [
  createData("0182  PARACETAMOL TABS 500 MG", "2.00", "10.00")
];

export default function MaterialUIPickers() {
  const classes = useStyles();

  return (
    <MuiPickersUtilsProvider utils={DateFnsUtils}>
      <form className={classes.formContainer} noValidate autoComplete="off">
        <Grid container>
          <Grid item xs={12}>
            <Paper className={classes.paper}>
              <Grid container>
                <Grid item xs={1} className={classes.paperHeaderBack}>
                  <IconButton>
                    <ChevronLeftIcon />
                  </IconButton>
                </Grid>
                <Grid container xs={11} alignItems="center">
                  <Grid item xs={12} className={classes.paperHeader}>
                    <Typography variant="h6">Claim Details</Typography>
                  </Grid>
                </Grid>
                <Grid item xs={12}>
                  <Divider />
                </Grid>
                <Grid item xs={3} className={classes.item}>
                  <TextField
                    id="standard-name"
                    label="Health Facility"
                    className={classes.textField}
                    value="VIHC001 - Juilöa Health Centre"
                    margin="normal"
                    readOnly={true}
                    inputProps={{
                      className: classes.readOnly
                    }}
                  />
                </Grid>
                <Grid item xs={3} className={classes.item} />
                <Grid item xs={3} className={classes.item}>
                  <KeyboardDatePicker
                    margin="normal"
                    id="mui-pickers-date"
                    label="Visit Date From"
                    fullWidth={true}
                    KeyboardButtonProps={{
                      "aria-label": "change date"
                    }}
                    readOnly={true}
                    inputProps={{
                      className: classes.readOnly
                    }}
                  />
                </Grid>
                <Grid item xs={3} className={classes.item}>
                  <KeyboardDatePicker
                    margin="normal"
                    id="mui-pickers-date"
                    label="Visit Date To"
                    fullWidth={true}
                    KeyboardButtonProps={{
                      "aria-label": "change date"
                    }}
                    readOnly={true}
                    inputProps={{
                      className: classes.readOnly
                    }}
                  />
                </Grid>

                <Grid item xs={3} className={classes.item}>
                  <TextField
                    id="standard-name"
                    label="Patient"
                    className={classes.textField}
                    value="Doni Ilina"
                    margin="normal"
                    readOnly={true}
                    inputProps={{
                      className: classes.readOnly
                    }}
                  />
                </Grid>

                <Grid item xs={3} className={classes.item}>
                  <TextField
                    id="standard-name"
                    label="Insurance"
                    className={classes.textField}
                    value="105000002"
                    margin="normal"
                    readOnly={true}
                    inputProps={{
                      className: classes.readOnly
                    }}
                  />
                </Grid>
                <Grid item xs={3} className={classes.item}>
                  <TextField
                    id="standard-name"
                    label="Guarantee No."
                    className={classes.textField}
                    value=""
                    margin="normal"
                    readOnly={true}
                    inputProps={{
                      className: classes.readOnly
                    }}
                  />
                </Grid>
                <Grid item xs={3} className={classes.item} />

                <Grid item xs={6} className={classes.item}>
                  <Grid container className={classes.innerContainer}>
                    <Grid item xs={6} className={classes.innerLeftItem}>
                      <TextField
                        id="standard-name"
                        label="Main Dg."
                        className={classes.textField}
                        value="A000 Cholera due to Vibrio cholerae 01, biovar cholerae"
                        margin="normal"
                        readOnly={true}
                        inputProps={{
                          className: classes.readOnly
                        }}
                      />
                    </Grid>
                    <Grid item xs={6} className={classes.innerRightItem}>
                      <TextField
                        id="visit-type-name"
                        label="Visit Type"
                        className={classes.textField}
                        value="Emergency"
                        margin="normal"
                        readOnly={true}
                        inputProps={{
                          className: classes.readOnly
                        }}
                      />
                    </Grid>
                    <Grid item xs={6} className={classes.innerLeftItem}>
                      <TextField
                        id="standard-name"
                        label="Sec Dg1"
                        className={classes.textField}
                        value="A001 Cholera due to Vibrio cholerae 01, biovar eltor"
                        margin="normal"
                        readOnly={true}
                        inputProps={{
                          className: classes.readOnly
                        }}
                      />
                    </Grid>
                    <Grid item xs={6} className={classes.innerRightItem}>
                      <TextField
                        id="standard-name"
                        label="Sec Dg2"
                        className={classes.textField}
                        value=""
                        margin="normal"
                        readOnly={true}
                        inputProps={{
                          className: classes.readOnly
                        }}
                      />
                    </Grid>
                    <Grid item xs={6} className={classes.innerLeftItem}>
                      <TextField
                        id="standard-name"
                        label="Sec Dg3"
                        className={classes.textField}
                        value=""
                        margin="normal"
                        readOnly={true}
                        inputProps={{
                          className: classes.readOnly
                        }}
                      />
                    </Grid>
                    <Grid item xs={6} className={classes.innerRightItem}>
                      <TextField
                        id="standard-name"
                        label="Sec Dg4"
                        className={classes.textField}
                        value=""
                        margin="normal"
                        readOnly={true}
                        inputProps={{
                          className: classes.readOnly
                        }}
                      />
                    </Grid>
                  </Grid>
                </Grid>
                <Grid item xs={6} className={classes.item}>
                  <Grid container className={classes.innerContainer}>
                    <Grid item xs={6} className={classes.innerLeftItem}>
                      <TextField
                        id="standard-name"
                        label="Claim No."
                        className={classes.textField}
                        value="CIB00001"
                        margin="normal"
                        readOnly={true}
                        inputProps={{
                          className: classes.readOnly
                        }}
                      />
                    </Grid>
                    <Grid item xs={6} className={classes.innerRightItem}>
                      <TextField
                        id="standard-name"
                        label="Claimed"
                        className={classes.textField}
                        value="5250"
                        margin="normal"
                        inputProps={{
                          className: classes.amount
                        }}
                      />
                    </Grid>
                    <Grid item xs={6} className={classes.innerLeftItem}>
                      <KeyboardDatePicker
                        margin="normal"
                        id="mui-pickers-date"
                        label="Date Claimed"
                        fullWidth={true}
                        KeyboardButtonProps={{
                          "aria-label": "change date"
                        }}
                        readOnly={true}
                        inputProps={{
                          className: classes.readOnly
                        }}
                        color="grey"
                      />
                    </Grid>
                    <Grid item xs={6} className={classes.innerRightItem}>
                      <TextField
                        id="standard-name"
                        label="Adjusted"
                        className={classes.textField}
                        value="250"
                        margin="normal"
                        inputProps={{
                          className: classes.amount
                        }}
                      />
                    </Grid>
                    <Grid item xs={6} className={classes.innerLeftItem}>
                      <TextField
                        id="standard-name"
                        label="Claim Administrator"
                        className={classes.textField}
                        value="UHOS0011	"
                        margin="normal"
                        readOnly={true}
                        inputProps={{
                          className: classes.readOnly
                        }}
                      />
                    </Grid>
                    <Grid item xs={6} className={classes.innerRightItem}>
                      <TextField
                        id="standard-name"
                        label="Approved"
                        className={classes.textField}
                        value="5000"
                        margin="normal"
                        inputProps={{
                          className: classes.amount
                        }}
                      />
                    </Grid>
                  </Grid>
                </Grid>
              </Grid>
            </Paper>
          </Grid>
          <Grid item xs={12}>
            <Paper className={classes.paper}>
              <Grid container>
                <Grid item xs={12} className={classes.paperHeader}>
                  <Typography variant="h6">Services (2)</Typography>
                </Grid>
                <Grid item xs={12}>
                  <Divider />
                </Grid>
                <Grid item xs={12}>
                  <Table className={classes.table} size="small">
                    <TableHead>
                      <TableRow>
                        <TableCell align="center">Code</TableCell>
                        <TableCell align="center">Quantity</TableCell>
                        <TableCell align="center">Price</TableCell>
                        <TableCell align="center">Explanation</TableCell>
                        <TableCell align="center">App. Qty</TableCell>
                        <TableCell align="center">App. Price</TableCell>
                        <TableCell align="center">App. Justification</TableCell>
                        <TableCell align="center">Status</TableCell>
                        <TableCell align="center">Valuated</TableCell>
                        <TableCell align="center">R</TableCell>
                        <TableCell align="center" />
                      </TableRow>
                    </TableHead>
                    <TableBody>
                      {rowsServices.map(row => (
                        <TableRow key={row.name}>
                          <TableCell component="th" scope="row" align="left">
                            {row.a}
                          </TableCell>
                          <TableCell align="right">{row.b}</TableCell>
                          <TableCell align="right">{row.c}</TableCell>
                          <TableCell align="left">{row.d}</TableCell>
                          <TableCell align="left">
                            <TextField
                              id="standard-name"
                              className={classes.textField}
                              value=""
                              margin="normal"
                              fullWidth={true}
                            />
                          </TableCell>
                          <TableCell align="left">
                            <TextField
                              id="standard-name"
                              className={classes.textField}
                              value=""
                              margin="normal"
                              fullWidth={true}
                            />
                          </TableCell>
                          <TableCell align="left">
                            <TextField
                              id="standard-name"
                              className={classes.textField}
                              value=""
                              margin="normal"
                              fullWidth={true}
                            />
                          </TableCell>
                          <TableCell>
                            <FormControl
                              fullWidth={true}
                              className={classes.formInput}
                            >
                              <InputLabel htmlFor="status">Status</InputLabel>
                              <Select
                                inputProps={{
                                  name: "status",
                                  id: "status"
                                }}
                              >
                                <MenuItem value={10}>Passed</MenuItem>
                                <MenuItem value={20}>Refused</MenuItem>
                              </Select>
                            </FormControl>
                          </TableCell>
                          <TableCell align="left" />
                          <TableCell align="left">0</TableCell>
                        </TableRow>
                      ))}
                    </TableBody>
                  </Table>
                </Grid>
              </Grid>
            </Paper>
          </Grid>
          <Grid item xs={12}>
            <Paper className={classes.paper}>
              <Grid container>
                <Grid item xs={12} className={classes.paperHeader}>
                  <Typography variant="h6">Items (1)</Typography>
                </Grid>
                <Grid item xs={12}>
                  <Divider />
                </Grid>
              </Grid>
              <Grid item xs={12}>
                <Table className={classes.table} size="small">
                  <TableHead>
                    <TableRow>
                      <TableCell align="center">Code</TableCell>
                      <TableCell align="center">Quantity</TableCell>
                      <TableCell align="center">Price</TableCell>
                      <TableCell align="center">Explanation</TableCell>
                      <TableCell align="center">App. Qty</TableCell>
                      <TableCell align="center">App. Price</TableCell>
                      <TableCell align="center">App. Justification</TableCell>
                      <TableCell align="center">Status</TableCell>
                      <TableCell align="center">Valuated</TableCell>
                      <TableCell align="center">R</TableCell>
                      <TableCell align="center" />
                    </TableRow>
                  </TableHead>
                  <TableBody>
                    {rowsItems.map(row => (
                      <TableRow key={row.name}>
                        <TableCell component="th" scope="row" align="left">
                          {row.a}
                        </TableCell>
                        <TableCell align="right">{row.b}</TableCell>
                        <TableCell align="right">{row.c}</TableCell>
                        <TableCell align="left">{row.d}</TableCell>
                        <TableCell align="left">
                          <TextField
                            id="standard-name"
                            className={classes.textField}
                            value=""
                            margin="normal"
                            fullWidth={true}
                          />
                        </TableCell>
                        <TableCell align="left">
                          <TextField
                            id="standard-name"
                            className={classes.textField}
                            value=""
                            margin="normal"
                            fullWidth={true}
                          />
                        </TableCell>
                        <TableCell align="left">
                          <TextField
                            id="standard-name"
                            className={classes.textField}
                            value=""
                            margin="normal"
                            fullWidth={true}
                          />
                        </TableCell>
                        <TableCell>
                          <FormControl
                            fullWidth={true}
                            className={classes.formInput}
                          >
                            <InputLabel htmlFor="status">Status</InputLabel>
                            <Select
                              inputProps={{
                                name: "status",
                                id: "status"
                              }}
                            >
                              <MenuItem value={10}>Passed</MenuItem>
                              <MenuItem value={20}>Refused</MenuItem>
                            </Select>
                          </FormControl>
                        </TableCell>
                        <TableCell align="left" />
                        <TableCell align="left">0</TableCell>
                      </TableRow>
                    ))}
                  </TableBody>
                </Table>
              </Grid>
            </Paper>
          </Grid>
          <Grid container>
            <Grid item xs={12}>
              <Paper className={classes.paper}>
                <Grid container>
                  <Grid item xs={12} className={classes.item}>
                    <TextField
                      id="standard-name"
                      label="Explanation"
                      className={classes.textField}
                      value=""
                      margin="normal"
                      fullWidth={true}
                    />
                  </Grid>
                  <Grid item xs={12} className={classes.item}>
                    <TextField
                      id="standard-name"
                      label="Adjustment"
                      className={classes.textField}
                      value=""
                      margin="normal"
                      fullWidth={true}
                    />
                  </Grid>
                </Grid>
              </Paper>
            </Grid>
          </Grid>
        </Grid>
      </form>
      <Fab color="primary" aria-label="Add" className={classes.fab}>
        <SaveAltIcon />
      </Fab>
    </MuiPickersUtilsProvider>
  );
}
